==> zio-aws-kafka_3-5.17.150.1-sources.jar: zio/aws/kafka/model/PublicAccess.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PublicAccess(`type`: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.PublicAccess = {
    import PublicAccess.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.PublicAccess
      .builder()
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.PublicAccess.ReadOnly =
    zio.aws.kafka.model.PublicAccess.wrap(buildAwsValue())
}
object PublicAccess {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.PublicAccess
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.PublicAccess =
      zio.aws.kafka.model.PublicAccess(`type`.map(value => value))
    def `type`: Option[__string]
    def getType: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.PublicAccess
  ) extends zio.aws.kafka.model.PublicAccess.ReadOnly {
    override val `type`: Option[__string] =
      scala.Option(impl.`type`()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.PublicAccess
  ): zio.aws.kafka.model.PublicAccess.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_3-5.17.208.1-sources.jar: zio/aws/kafka/model/PublicAccess.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class PublicAccess(`type`: Optional[__string] = Optional.Absent) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.PublicAccess = {
    import PublicAccess.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.PublicAccess
      .builder()
      .optionallyWith(`type`.map(value => value: java.lang.String))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.PublicAccess.ReadOnly =
    zio.aws.kafka.model.PublicAccess.wrap(buildAwsValue())
}
object PublicAccess {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.PublicAccess
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.PublicAccess =
      zio.aws.kafka.model.PublicAccess(`type`.map(value => value))
    def `type`: Optional[__string]
    def getType: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.PublicAccess
  ) extends zio.aws.kafka.model.PublicAccess.ReadOnly {
    override val `type`: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.`type`())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.PublicAccess
  ): zio.aws.kafka.model.PublicAccess.ReadOnly = new Wrapper(impl)
}
